<?php
/**
*
* @package Donation MOD with Multiple Payment Options
* @version $Id$
* @copyright (c) 2012 Siropu, www.siropu.com
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
define('IN_PHPBB', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : './';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup('mods/donation');

// Check if the mod is installed
if (!$config['donation_mod_version'])
{
	if ($user->data['user_type'] == USER_FOUNDER)
	{
		trigger_error($user->lang['NOT_INSTALLED'], E_USER_NOTICE);
	}
	else
	{
	    trigger_error($user->lang['DISABLED'], E_USER_NOTICE);
	}
}

// Check if the mod is enabled
if (!$config['donation_enable'])
{
    trigger_error($user->lang['DISABLED'], E_USER_NOTICE);
}

// Check if non-members are allowed to donate
if (!$config['non_members_donations_enable'] && $user->data['user_id'] == ANONYMOUS)
{
    trigger_error($user->lang['NO_NON_MEMBERS_DONATIONS'], E_USER_NOTICE);
}

// Pages
$action = request_var('action', '');

switch ($action)
{
    case 'paypal':

	    if (!$config['paypal_enable'])
        {
            trigger_error($user->lang['PAYPAL_DISABLED'], E_USER_NOTICE);
        }

	    $page_title    = $user->lang['PAYPAL_TITLE'];
	    $page_template = 'donate/paypal.html';

	break;

	case 'payza':

		if (!$config['payza_enable'])
        {
            trigger_error($user->lang['PAYZA_DISABLED'], E_USER_NOTICE);
        }

	    $page_title    = $user->lang['PAYZA_TITLE'];
	    $page_template = 'donate/payza.html';

	break;

	case 'moneybookers':

		if (!$config['moneybookers_enable'])
        {
            trigger_error($user->lang['MONEYBOOKERS_DISABLED'], E_USER_NOTICE);
        }

	    $page_title    = $user->lang['MONEYBOOKERS_TITLE'];
	    $page_template = 'donate/moneybookers.html';

	break;

	case 'libertyreserve':

		if (!$config['libertyreserve_enable'])
        {
            trigger_error($user->lang['LIBERTYRESERVE_DISABLED'], E_USER_NOTICE);
        }

	    $page_title    = $user->lang['LIBERTYRESERVE_TITLE'];
	    $page_template = 'donate/libertyreserve.html';

	break;

	case 'webmoney':

		if (!$config['webmoney_enable'])
        {
            trigger_error($user->lang['WEBMONEY_DISABLED'], E_USER_NOTICE);
        }

	    $page_title    = $user->lang['WEBMONEY_TITLE'];
	    $page_template = 'donate/webmoney.html';

	break;
	
	case 'success':

	    $page_title    = $user->lang['SUCCESS_TITLE'];
        $page_template = 'donate/success.html';

    break;

	case 'cancel':

	    $page_title    = $user->lang['CANCEL_TITLE'];
        $page_template = 'donate/cancel.html';

    break;

	default;

	    $page_title    = $user->lang['BODY_TITLE'];
        $page_template = 'donate/body.html';

    break;
}

// Get donation config data
$sql = 'SELECT * 
    FROM ' . DONATION_CONFIG_TABLE;
$result = $db->sql_query($sql);

$donation_config = array();
while($row = $db->sql_fetchrow($result))
{
	$donation_config[$row['config_name']] = $row['config_value'];
}
$db->sql_freeresult($result);

// Get the last 5 donations
$sql = 'SELECT *
	FROM ' . DONATION_DONORS_TABLE . '
	ORDER BY donor_id DESC';
$result = $db->sql_query_limit($sql, 5, 0);

while ($row = $db->sql_fetchrow($result))
{
	$template->assign_block_vars('donors_list', array(
		'DONOR_USERNAME'    => $row['donor_username'],
		'DONATION_AMOUNT'   => $row['donation_amount'],
		'DONATION_CURRENCY' => $row['donation_currency'],
		'DONATION_METHOD'   => $row['donation_method'],
		'DONATION_DATE'     => (isset($row['donation_date']) && is_numeric($row['donation_date'])) ? $user->format_date($row['donation_date']) : $row['donation_date'],
		)
	);
}
$db->sql_freeresult($result);

// Calculate percentage
$percentage = floor($config['donation_goal_amount_received'] * 100 / $config['donation_goal_amount']);

// Donation goal progressbar
function progressbar()
{
    global $percentage;

    if ($percentage <= 100)
	{
	    if ($percentage <= 2)
		{
	        return '<div id="donation_progressbar" style="width:' . $percentage . '%;"><span id="fix">' . $percentage . '%</span></div>';
		}
		else
		{
		    return '<div id="donation_progressbar" style="width:' . $percentage . '%;"><span>' . $percentage . '%</span></div>';
		}
	}
	else
	{
	    return '<div id="donation_progressbar" style="width:100%;"><span>' . $percentage . '%</span></div>';
	}
}

// Avoid negative values in the goal statistics
function goal_status()
{
    global $percentage, $config;

    if ($percentage <= 100)
	{
	    return $config['donation_goal_amount'] - $config['donation_goal_amount_received'];
	}
	else
	{
	    return 0;
	}
}

// Generate currency list
function currency_list($list, $default, $lr_prefix = null)
{
    $currency_list = '';

    foreach(explode(',',$list) as $currency)
    {
        if ($currency == $default)
	    {
	        $currency_list .= '<option value="' . $lr_prefix . $currency . '" selected="selected">' . $currency . '</option>';
	    }
	    else
	    {
	        $currency_list .= '<option value="' . $lr_prefix . $currency . '">' . $currency . '</option>';
	    }
	}
	return $currency_list;
}

// Replace USERNAME with the real username
function display_username($page)
{
    global $user;

    if (preg_match("/USERNAME/", html_entity_decode($page)))
    {
        $donation_page = str_replace("USERNAME", $user->data['username'], html_entity_decode($page));
    }
    else
    {
        $donation_page = html_entity_decode($page);
    }
	return $donation_page;
}

// Template functionality
$template->assign_vars(array(
    'PAYPAL_ENABLE'                            => $config['paypal_enable'],
	'PAYPAL_EMAIL'                             => $config['paypal_email'],
	'PAYPAL_MINIMUM'                           => $config['paypal_minimum'],
	'PAYPAL_CURRENCY'                          => $config['paypal_currency'],
	'PAYPAL_PREFERRED_CURRENCIES_LIST'         => currency_list($config['paypal_preferred_currencies'], $config['paypal_currency']),
	'PAYPAL_ALERT_MESSAGE'                     => sprintf($user->lang['MINIMUM_DONATION_MESSAGE'], $config['paypal_minimum'], $config['paypal_currency']),

	'PAYZA_ENABLE'                             => $config['payza_enable'],
	'PAYZA_EMAIL'	                           => $config['payza_email'],
	'PAYZA_MINIMUM'                            => $config['payza_minimum'],
	'PAYZA_CURRENCY'                           => $config['payza_currency'],
	'PAYZA_PREFERRED_CURRENCIES_LIST'          => currency_list($config['payza_preferred_currencies'], $config['payza_currency']),
	'PAYZA_ALERT_MESSAGE'                      => sprintf($user->lang['MINIMUM_DONATION_MESSAGE'], $config['payza_minimum'], $config['payza_currency']),

	'MONEYBOOKERS_ENABLE'                      => $config['moneybookers_enable'],
	'MONEYBOOKERS_EMAIL'	                   => $config['moneybookers_email'],
	'MONEYBOOKERS_MINIMUM'	                   => $config['moneybookers_minimum'],
	'MONEYBOOKERS_CURRENCY'                    => $config['moneybookers_currency'],
	'MONEYBOOKERS_PREFERRED_CURRENCIES_LIST'   => currency_list($config['moneybookers_preferred_currencies'], $config['moneybookers_currency']),
	'MONEYBOOKERS_ALERT_MESSAGE'               => sprintf($user->lang['MINIMUM_DONATION_MESSAGE'], $config['moneybookers_minimum'], $config['moneybookers_currency']),
	
	'LIBERTYRESERVE_ENABLE'                    => $config['libertyreserve_enable'],
	'LIBERTYRESERVE_ACCOUNT'                   => $config['libertyreserve_account'],
	'LIBERTYRESERVE_MINIMUM'                   => $config['libertyreserve_minimum'],
	'LIBERTYRESERVE_CURRENCY'                  => $config['libertyreserve_currency'],
	'LIBERTYRESERVE_PREFERRED_CURRENCIES_LIST' => currency_list($config['libertyreserve_preferred_currencies'], $config['libertyreserve_currency'], 'LR'),
	'LIBERTYRESERVE_STORE'                     => $config['ipn_libertyreserve_store_name'],
	'LIBERTYRESERVE_ALERT_MESSAGE'             => sprintf($user->lang['MINIMUM_DONATION_MESSAGE'], $config['libertyreserve_minimum'], $config['libertyreserve_currency']),

    'WEBMONEY_ENABLE'                          => $config['webmoney_enable'],
	'WEBMONEY_PURSE_WMZ'                       => $config['webmoney_purse_wmz'],
	'WEBMONEY_PURSE_WMR'                       => $config['webmoney_purse_wmr'],
	'WEBMONEY_PURSE_WME'                       => $config['webmoney_purse_wme'],
	'WEBMONEY_PURSE_WMU'                       => $config['webmoney_purse_wmu'],
	'WEBMONEY_PURSE_WMB'                       => $config['webmoney_purse_wmb'],
	'WEBMONEY_PURSE_WMG'                       => $config['webmoney_purse_wmg'],
	'WEBMONEY_MINIMUM'                         => $config['webmoney_minimum'],
	'WEBMONEY_CURRENCY'                        => $config['webmoney_currency'],
	'WEBMONEY_ALERT_MESSAGE'                   => sprintf($user->lang['MINIMUM_DONATION_MESSAGE'], $config['webmoney_minimum'], $config['webmoney_currency']),

	'GOAL_ENABLE'                              => $config['donation_goal_enable'],
	'GOAL_AMOUNT_RECEIVED'                     => $config['donation_goal_amount_received'],
	'GOAL_AMOUNT'                              => $config['donation_goal_amount'],
	'GOAL_CURRENCY'                            => $config['donation_goal_currency'],
	'GOAL_PROGRESSBAR'                         => progressbar(),
	'GOAL_UNTIL'                               => goal_status(),

	'DONORS_LAST_FIVE_ENABLE'                  => $config['donors_last_five_enable'],
	
	'DONATION_BODY_MESSAGE'                    => display_username($donation_config['donation_body']),
	'DONATION_SUCCESS_MESSAGE'                 => display_username($donation_config['donation_success']),
	'DONATION_CANCEL_MESSAGE'                  => display_username($donation_config['donation_cancel']),

	'DONATION_DESCRIPTION'                     => $user->lang['DONATION_TO'] . ' ' . $config['sitename'],
	'U_DONATE_SUCCESS'                         => generate_board_url() . "/donate.$phpEx?action=success",
	'U_DONATE_CANCEL'                          => generate_board_url() . "/donate.$phpEx?action=cancel",
	
	'IPN_ENABLE'                               => $config['donation_ipn_enable'],
	'U_PAYPAL_IPN'                             => generate_board_url() . "/donation/ipn.$phpEx?action=paypal",
	'U_PAYZA_IPN'                              => generate_board_url() . "/donation/ipn.$phpEx?action=payza",
	'U_MONEYBOOKERS_IPN'                       => generate_board_url() . "/donation/ipn.$phpEx?action=moneybookers",
	'U_LIBERTYRESERVE_IPN'                     => generate_board_url() . "/donation/ipn.$phpEx?action=libertyreserve",
	'U_WEBMONEY_IPN'                           => generate_board_url() . "/donation/ipn.$phpEx?action=webmoney",
    )
);

// Generate breadcrumbs
$template->assign_block_vars('navlinks', array(
    'FORUM_NAME'         => $user->lang['BODY_TITLE'],
    'U_VIEW_FORUM'       => append_sid("{$phpbb_root_path}donate.$phpEx"),
    )
);

// Output the page
page_header($page_title);
$template->set_filenames(array('body' => $page_template));

make_jumpbox(append_sid("{$phpbb_root_path}viewforum.$phpEx"));
page_footer();

?>